﻿namespace QuickAccess.Browser.Commands {
    #region Imported Namespaces

    using System;
    using EventAggregator;
    using GraphicsManager.Commands;
    using GraphicsManager.ViewModels;

    #endregion

    public class BaseCommand {

        private IEventAggregator _eventAggregator;

        protected IRelayCommand InternalCommand
        {
            get { return new RelayCommand( this.ExecuteFunction, this.CanExecuteFunction ); }
        }

        public IPageViewModel ViewModel { get; set; }

        public Action CreateInstance { get; set; }

        public Func<bool> ViewModelPrepared { get; set; }

        public string PageName { get; set; }

        public IEventAggregator EventAggregator
        {
            get { return this._eventAggregator ?? ( this._eventAggregator = EventAggregatorFactory.Instance ); }
            set { this._eventAggregator = value; }
        }

        protected bool CanExecuteFunction( object obj ) {
            return true;
        }

        protected void ExecuteFunction( object obj ) {
            if ( this.CreateInstance == null ) { return; }

            this.CreateInstance.Invoke( );

            var page = this.ViewModel;

            if ( page == null ||
                 this.ViewModelPrepared == null ||
                 !this.ViewModelPrepared.Invoke( ) ) {
                return;
            }
        }
    }
}
